@@ -4,7 +4,6 @@ import typing as ty
 
 if ty.TYPE_CHECKING:
    from .context import Context
-   ConfigIdentifier: ty.TypeAlias = ty.Union[Context, str, int]
 
 import yaml
 import pathlib as pl
@@ -35,12 +34,12 @@ class Config(metaclass=aurcore.util.Singleton):
       self.cached: clc.OrderedDict = clc.OrderedDict()  # mypy weirdness
       self.locks: ty.Dict[int, asyncio.locks.Lock] = clc.defaultdict(asyncio.locks.Lock)
 
-   def _write_config_file(self, config_id, data):
+   def _write_config_file(self, config_id: ty.Union[int, str], data):
       local_config_path: pl.Path = self.config_dir / f"{config_id}.yaml"
       with local_config_path.open("w") as f:
          yaml.safe_dump(data, f)
 
-   def _load_config_file(self, config_id):
+   def _load_config_file(self, config_id: ty.Union[int, str]):
       local_config_path: pl.Path = self.config_dir / f"{config_id}.yaml"
       try:
          with local_config_path.open("r") as f:
@@ -49,35 +48,37 @@ class Config(metaclass=aurcore.util.Singleton):
          local_config = {}
       return local_config
 
-   def load_config(self, identifiable: ConfigIdentifier):
-      identifier = identifiable.config_identifier if hasattr(identifiable, "config_identifier") else str(identifiable)
+   # def load_config(self, identifiable: Context):
+   #    identifier = identifiable.config_identifier
+   #    if identifier in self.cached:
+   #       self.cached.move_to_end(identifier, last=False)
+   #       configs = self.cached[identifier]
+   #    else:
+   #       local_config = self._load_config_file(identifier)
+   #       combined_dict = {**self.base_config, **local_config}
+   #       cleaned_dict = {k: combined_dict[k] for k in self.base_config}
+   #       if cleaned_dict != local_config:
+   #          self._write_config_file(identifier, cleaned_dict)
+   #
+   #       self.cached[identifier] = cleaned_dict
+   #       if len(self.cached) > CACHED_CONFIGS:
+   #          self.cached.popitem()
+   #
+   #       configs = cleaned_dict
+   #    return configs
+
+   def of(self, identifiable: Context) -> ty.Dict[str, ty.Any]:
+      identifier = identifiable.config_identifier
       if identifier in self.cached:
          self.cached.move_to_end(identifier, last=False)
          configs = self.cached[identifier]
       else:
          local_config = self._load_config_file(identifier)
+         print(local_config)
          combined_dict = {**self.base_config, **local_config}
          cleaned_dict = {k: combined_dict[k] for k in self.base_config}
-         if cleaned_dict != local_config:
-            self._write_config_file(identifier, cleaned_dict)
-
-         self.cached[identifier] = cleaned_dict
-         if len(self.cached) > CACHED_CONFIGS:
-            self.cached.popitem()
-
-         configs = cleaned_dict
-      return configs
-
-   def of(self, identifiable: ConfigIdentifier) -> ty.Dict[str, ty.Any]:
-      identifier = identifiable.config_identifier if hasattr(identifiable, "config_identifier") else str(identifiable)
-      if identifier in self.cached:
-         self.cached.move_to_end(identifier, last=False)
-         configs = self.cached[identifier]
-      else:
-         local_config = self.load_config(identifier)
-         combined_dict = {**self.base_config, **local_config}
-         cleaned_dict = {k: combined_dict[k] for k in self.base_config}
-
+         print(cleaned_dict)
+         print(cleaned_dict == local_config)
          if cleaned_dict != local_config:
             self._write_config_file(identifier, cleaned_dict)
 
@@ -91,8 +92,8 @@ class Config(metaclass=aurcore.util.Singleton):
       return configs
 
    @contextlib.asynccontextmanager
-   async def writeable_conf(self, identifiable: ConfigIdentifier):
-      config_id = identifiable.config_identifier if hasattr(identifiable, "config_identifier") else str(identifiable)
+   async def writeable_conf(self, identifiable: Context):
+      config_id = identifiable.config_identifier
       async with self.locks[config_id]:
          output_dict = self._load_config_file(config_id)
          try:
